Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(853)

Unified Diff: chrome/browser/chrome_browser_main.cc

Issue 2918203002: cros: Fix loading user profile w/o UserSessionManager (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/accessibility/accessibility_manager_browsertest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_browser_main.cc
diff --git a/chrome/browser/chrome_browser_main.cc b/chrome/browser/chrome_browser_main.cc
index eafb51360e975e1973b4c655d02e7094fbe5e100..a2ae2417053f64c861aedafe1bb28de819c32be9 100644
--- a/chrome/browser/chrome_browser_main.cc
+++ b/chrome/browser/chrome_browser_main.cc
@@ -427,11 +427,11 @@ Profile* CreatePrimaryProfile(const content::MainFunctionParams& parameters,
Profile* profile = nullptr;
#if defined(OS_CHROMEOS) || defined(OS_ANDROID)
// On ChromeOS and Android the ProfileManager will use the same path as the
// one we got passed. GetActiveUserProfile will therefore use the correct path
// automatically.
DCHECK_EQ(user_data_dir.value(),
g_browser_process->profile_manager()->user_data_dir().value());
- profile = ProfileManager::GetActiveUserProfile();
+ profile = ProfileManager::CreateInitialProfile();
// TODO(port): fix this. See comments near the definition of |user_data_dir|.
// It is better to CHECK-fail here than it is to silently exit because of
« no previous file with comments | « no previous file | chrome/browser/chromeos/accessibility/accessibility_manager_browsertest.cc » ('j') | no next file with comments »
@@ -427,11 +427,11 @@ Profile* CreatePrimaryProfile(const content::MainFunctionParams& parameters,
#if defined(OS_CHROMEOS) || defined(OS_ANDROID)
// On ChromeOS and Android the ProfileManager will use the same path as the
- // one we got passed. GetActiveUserProfile will therefore use the correct path
+ // one we got passed. CreateInitialProfile will therefore use the correct path
// automatically.
DCHECK_EQ(user_data_dir.value(),

Powered by Google App Engine
This is Rietveld 408576698